package com.ruoyi.zhiyuanzhe.mapper;

import com.ruoyi.zhiyuanzhe.domain.BActivity;
import com.ruoyi.zhiyuanzhe.domain.BActivityUser;
import com.ruoyi.zhiyuanzhe.domain.BPersonTags;
import com.ruoyi.zhiyuanzhe.domain.request.ActivityInviteRequest;
import com.ruoyi.zhiyuanzhe.domain.request.EventRecommendationsRequest;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 活动人员关联持久层
 *
 * @author wu
 * @since 2023/9/28 15:39
 */
public interface ActivityUserMapper {

    /**
     * 批量新增数据
     *
     * @param list 人员活动关联数据
     */
    void add(BActivityUser list);

    /**
     * 删除所有用户
     *
     * @param activityId – 活动标签
     */
    void delByActivityId(Long activityId);

    /**
     * 查询人员信息
     *
     * @param status     状态
     * @param activityId 活动id
     * @return 人员信息
     */
    List<BPersonTags> findUserByStatusAndActivityId(@Param("status") Integer status, @Param("activityId") Long activityId);

    /**
     * 邀请人员
     *
     * @param req 活动id和用户id
     */
    void invite(@Param("req") ActivityInviteRequest req);

    /**
     * 活动推荐
     *
     * @param req 活动搜索条件
     * @return 活动信息
     */
    List<BActivity> eventRecommendations(@Param("req") EventRecommendationsRequest req);

    /**
     * 报名
     *
     * @param req 活动id和用户id
     */
    void enroll(@Param("req") ActivityInviteRequest req);

    /**
     * 活动邀请列表
     *
     * @param req 活动搜索条件
     * @return 活动信息
     */
    List<BActivity> eventInvitations(@Param("req") EventRecommendationsRequest req);

    /**
     * 根据id修改状态
     *
     * @param id     id
     * @param status 状态
     */
    void inviteTwo(@Param("id") Long id, @Param("status") int status);

    /**
     * 根据活动用户匹配表id获取用户标签信息
     *
     * @param id 活动用户匹配表id
     * @return 响应类
     */
    BActivityUser findById(@Param("id") Long id);
}

