package com.ruoyi.zhiyuanzhe.service;


import com.ruoyi.zhiyuanzhe.domain.BActivity;
import com.ruoyi.zhiyuanzhe.domain.BActivityUser;
import com.ruoyi.zhiyuanzhe.domain.request.ActivityInviteRequest;
import com.ruoyi.zhiyuanzhe.domain.request.EnrollApprovalRequest;
import com.ruoyi.zhiyuanzhe.domain.request.EventRecommendationsRequest;
import com.ruoyi.zhiyuanzhe.domain.response.ActivityResponse;

import java.util.List;

/**
 * 活动管理Service接口
 *
 * @author ruoyi
 * @date 2023-09-18
 */
public interface IBActivityService {
    /**
     * 查询活动管理
     *
     * @param id 活动管理主键
     * @return 活动管理
     */
    ActivityResponse selectBActivityById(Long id);

    /**
     * 查询活动管理列表
     *
     * @param bActivity 活动管理
     * @return 活动管理集合
     */
    List<BActivity> selectBActivityList(BActivity bActivity);

    /**
     * 新增活动管理
     *
     * @param bActivity 活动管理
     */
    void insertBActivity(BActivity bActivity);

    /**
     * 修改活动管理
     *
     * @param bActivity 活动管理
     * @return 结果
     */
    void updateBActivity(BActivity bActivity);

    /**
     * 批量删除活动管理
     *
     * @param ids 需要删除的活动管理主键集合
     * @return 结果
     */
    int deleteBActivityByIds(Long[] ids);

    /**
     * 删除活动管理信息
     *
     * @param id 活动管理主键
     * @return 结果
     */
    int deleteBActivityById(Long id);

    /**
     * 邀请人员
     *
     * @param req 活动id和用户id
     */
    void invite(ActivityInviteRequest req);

    /**
     * 活动推荐
     *
     * @param req 活动搜索条件
     * @return 活动信息
     */
    List<BActivity> eventRecommendations(EventRecommendationsRequest req);


    /**
     * 报名
     *
     * @param req 活动id和用户id
     */
    void enroll(ActivityInviteRequest req);

    /**
     * 活动邀请列表
     *
     * @param req 活动搜索条件
     * @return 活动信息
     */
    List<BActivity> eventInvitations(EventRecommendationsRequest req);

    /**
     * 根据id修改状态
     *
     * @param id     id
     * @param status 状态
     */
    void inviteTwo(Long id, int status);

    /**
     * 报名审批
     *
     * @param req 活动人员匹配度关联表id和状态
     * @return 响应类
     */
    void enrollApproval(EnrollApprovalRequest req);

    /**
     * 根据活动状态查询活动
     *
     * @param status 活动状态1：进行中，2：停止
     * @return 活动
     */
    List<BActivity> findByStatus(int status);

    /**
     * 批量修改活动状态
     *
     * @param ids id集合
     */
    void updateStatusByIds(List<Long> ids);

    /**
     * 根据活动用户匹配表id获取用户标签信息
     *
     * @param id 活动用户匹配表id
     * @return 响应类
     */
    BActivityUser findByActivityUserId(Long id);
}
